#!/usr/bin/env python3
# -*- mode: python; coding: utf-8 -*-

"""Functions for fetching and displaying XKCD comics."""

import os.path
import argparse
import shutil

import requests
from bs4 import BeautifulSoup
from PIL import Image

PATH_ROOT = os.path.dirname(os.path.realpath(__file__))

def get_comic_url(comic_num):
    """Get the comic url from its main page."""
    url = "http://xkcd.com/" + str(comic_num)
    if comic_num == 0:
        url = "https://c.xkcd.com/random/comic"
    content = requests.get(url)
    soup = BeautifulSoup(content.text, 'html.parser')
    img = soup.find(id="comic").find("img")
    return "http:"+img.get("src")

def get_comic(url, filename):
    """Download url into filename."""
    if not os.path.isfile(filename):
        response = requests.get(url, stream=True)
        with open(filename, 'wb') as out_file:
            shutil.copyfileobj(response.raw, out_file)
        del response

def show(filename):
    """Show the specified image file, given by its filename."""
    image = Image.open(filename)
    image.show()

def main():
    """
    Main function of the xkcd application.

    It reads an optional comic number on the command-line,
    and displays that comic, or a random one if no number is
    specified.
    """

    # Read optional comic number on command-line
    parser = argparse.ArgumentParser()
    parser.add_argument("comic_num",
                        help="number identifying the xkcd to display",
                        type=int, default=0, nargs='?')
    args = parser.parse_args()
    comic_number = args.comic_num

    # Display XKCD image to wait for the rest
    show(PATH_ROOT + "/xkcd.png")

    # Get comic image and display it
    filename = PATH_ROOT + "/" + str(comic_number) + '.jpg'
    get_comic(get_comic_url(comic_number), filename)
    show(filename)

if __name__ == "__main__":
    main()
